import { ConnectionState, IConnection, Message } from './connection';
import { GameContext } from './game-context';
import { GameContextSnapshot } from './game-context-snapshot';
import { ITransport, TransactionResult } from './transport';
import { IWallet } from './wallet';
import { Handler } from './handler';
import { IEncryptor } from './encryptor';
import { EntryType, GameAccount, IToken, PlayerProfile } from './accounts';
import { TxState } from './tx-state';
import { Client } from './client';
import { GameEvent, ICustomEvent } from './events';
import { IStorage } from './storage';
import { DecryptionCache } from './decryption-cache';
export type EventCallbackFunction = (context: GameContextSnapshot, state: Uint8Array, event: GameEvent | undefined) => void;
export type MessageCallbackFunction = (message: Message) => void;
export type TxStateCallbackFunction = (txState: TxState) => void;
export type OnConnectionStateCallbackFunction = (connState: ConnectionState) => void;
export type AppClientInitOpts = {
    transport: ITransport;
    wallet: IWallet;
    gameAddr: string;
    onEvent: EventCallbackFunction;
    onMessage?: MessageCallbackFunction;
    onTxState?: TxStateCallbackFunction;
    onConnectionState?: OnConnectionStateCallbackFunction;
    storage?: IStorage;
};
export type JoinOpts = {
    amount: bigint;
    position?: number;
};
export type GameInfo = {
    title: string;
    maxPlayers: number;
    minDeposit?: bigint;
    maxDeposit?: bigint;
    entryType: EntryType;
    token: IToken;
    tokenAddr: string;
    bundleAddr: string;
    data: Uint8Array;
    dataLen: number;
};
export declare class AppClient {
    #private;
    constructor(gameAddr: string, handler: Handler, wallet: IWallet, client: Client, transport: ITransport, connection: IConnection, gameContext: GameContext, onEvent: EventCallbackFunction, onMessage: MessageCallbackFunction | undefined, onTxState: TxStateCallbackFunction | undefined, onConnectionState: OnConnectionStateCallbackFunction | undefined, encryptor: IEncryptor, info: GameInfo, decryptionCache: DecryptionCache);
    static initialize(opts: AppClientInitOpts): Promise<AppClient>;
    get playerAddr(): string;
    get gameAddr(): string;
    get gameContext(): GameContext;
    /**
     * Get player profile by its wallet address.
     */
    getProfile(addr: string): Promise<PlayerProfile | undefined>;
    invokeEventCallback(event: GameEvent | undefined): Promise<void>;
    __initializeState(gameAccount: GameAccount): Promise<void>;
    __getGameAccount(): Promise<GameAccount>;
    /**
     * Connect to the transactor and retrieve the event stream.
     */
    attachGame(): Promise<void>;
    /**
     * Join game.
     */
    join(params: JoinOpts): Promise<TransactionResult<void>>;
    /**
     * Submit an event.
     */
    submitEvent(raw: Uint8Array): Promise<void>;
    submitEvent(customEvent: ICustomEvent): Promise<void>;
    /**
     * Submit a message, contains arbitrary content.
     */
    submitMessage(message: string): Promise<void>;
    /**
     * Get hidden knowledge by random id. The result contains both
     * public and private information.  For performance reason, it's
     * better to cache the result somewhere instead of calling this
     * function frequently.
     */
    getRevealed(randomId: number): Promise<Map<number, string>>;
    /**
     * Close current event subscription.
     */
    close(): Promise<void>;
    /**
     * Exit current game.
     */
    exit(): Promise<void>;
    exit(keepConnection: boolean): Promise<void>;
    get info(): GameInfo;
}
