import { GameAccount, INft, IToken, PlayerProfile, TokenWithBalance } from './accounts';
import { IStorage } from './storage';
import { CreateGameAccountParams, ITransport, TransactionResult } from './transport';
import { IWallet } from './wallet';
export type AppHelperInitOpts = {
    transport: ITransport;
    storage?: IStorage;
};
/**
 * The helper for common interaction.
 *
 * @public
 * @beta
 */
export declare class AppHelper {
    #private;
    constructor(transport: ITransport);
    constructor(opts: AppHelperInitOpts);
    /**
     * Get the game account by game address.
     *
     * @param addr - The address of game account
     * @returns An object of GameAccount or undefined when not found
     */
    getGame(addr: string): Promise<GameAccount | undefined>;
    /**
     * Create a game account.
     *
     * @param wallet - The wallet adapter to sign the transaction
     * @param params - Parameters for game creation
     * @returns The address of created game
     */
    createGame(wallet: IWallet, params: CreateGameAccountParams): Promise<TransactionResult<string>>;
    /**
     * Register a game to a registration account.
     *
     * @param wallet - The wallet adapter to sign the transaction
     * @param gameAddr - The address of game account.
     * @param regAddr - The address of registration account.
     */
    registerGame(wallet: IWallet, gameAddr: string, regAddr: string): Promise<TransactionResult<void>>;
    /**
     * Create a player profile.
     *
     * @param wallet - The wallet adapter to sign the transaction
     * @param nick - The nick name
     * @param pfp - The address of avatar NFT
     */
    createProfile(wallet: IWallet, nick: string, pfp: string | undefined): Promise<TransactionResult<void>>;
    /**
     * Get a player profile.
     *
     * @param addr - The address of player profile account
     * @returns The player profile account or undefined when not found
     */
    getProfile(addr: string): Promise<PlayerProfile | undefined>;
    /**
     * List games from a list of registration accounts.
     *
     * @param registrationAddrs - The addresses of registration accounts
     * @return A list of games
     */
    listGames(registrationAddrs: string[]): Promise<GameAccount[]>;
    /**
     * List available tokens.
     *
     * @return A list of token info.
     */
    listTokens(): Promise<IToken[]>;
    /**
     * List all nfts owned by a wallet.
     *
     * @param walletAddr - wallet address.
     * @param collectionName - The collection name for filtering, pass `undefined` for no filtering.
     *
     * @return A list of nfts.
     */
    listNfts(walletAddr: string, collection?: string | undefined): Promise<INft[]>;
    /**
     * Get NFT by address
     *
     * @param addr - The address of NFT
     */
    getNft(addr: string): Promise<INft | undefined>;
    /**
     * Fetch tokens and balances
     *
     * @param walletAddr - The player's wallet address
     *
     * @return The list of tokens with `amount` and `uiAmount` added.
     */
    listTokensWithBalance(walletAddr: string): Promise<TokenWithBalance[]>;
}
//# sourceMappingURL=app-helper.d.ts.map